==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.md <==
# AwsIdentityAccessManagementPermissions


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')
```



| Illustration | AwsIdentityAccessManagementPermissions | AwsIdentityAccessManagementPermissionsCard | AwsIdentityAccessManagementPermissionsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.png) | ![illustration for AwsIdentityAccessManagementPermissions](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.Local.png) | ![illustration for AwsIdentityAccessManagementPermissionsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissionsCard.Local.png) | ![illustration for AwsIdentityAccessManagementPermissionsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissionsGroup.Local.png) |




## AwsIdentityAccessManagementPermissions

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissions
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissions('AwsIdentityAccessManagementPermissions', 'Aws Identity Access Management Permissions', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissions
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissions('AwsIdentityAccessManagementPermissions', 'Aws Identity Access Management Permissions', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementPermissionsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsCard('AwsIdentityAccessManagementPermissionsCard', 'Aws Identity Access Management Permissions Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsCard('AwsIdentityAccessManagementPermissionsCard', 'Aws Identity Access Management Permissions Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementPermissionsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsGroup('AwsIdentityAccessManagementPermissionsGroup', 'Aws Identity Access Management Permissions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsGroup('AwsIdentityAccessManagementPermissionsGroup', 'Aws Identity Access Management Permissions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.md <==
# AwsIdentityAccessManagementPermissions


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')
```



| Illustration | AwsIdentityAccessManagementPermissions | AwsIdentityAccessManagementPermissionsCard | AwsIdentityAccessManagementPermissionsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.png) | ![illustration for AwsIdentityAccessManagementPermissions](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions.Local.png) | ![illustration for AwsIdentityAccessManagementPermissionsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissionsCard.Local.png) | ![illustration for AwsIdentityAccessManagementPermissionsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissionsGroup.Local.png) |




## AwsIdentityAccessManagementPermissions

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissions
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissions('AwsIdentityAccessManagementPermissions', 'Aws Identity Access Management Permissions', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissions
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissions('AwsIdentityAccessManagementPermissions', 'Aws Identity Access Management Permissions', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementPermissionsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsCard('AwsIdentityAccessManagementPermissionsCard', 'Aws Identity Access Management Permissions Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsCard('AwsIdentityAccessManagementPermissionsCard', 'Aws Identity Access Management Permissions Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementPermissionsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsGroup('AwsIdentityAccessManagementPermissionsGroup', 'Aws Identity Access Management Permissions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementPermissionsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementPermissions')

' renders the element
AwsIdentityAccessManagementPermissionsGroup('AwsIdentityAccessManagementPermissionsGroup', 'Aws Identity Access Management Permissions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
